Stan Math Library: stan/math/prim/mat/fun/promote_common.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

promote_common.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_PROMOTE_COMMON_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_PROMOTE_COMMON_HPP
3
4 #include <stan/math/prim/mat/fun/common_type.hpp>
5 #include <stan/math/prim/mat/fun/promoter.hpp>
6
7 namespace stan {
8
9 namespace math {
10
11 template <typename T1, typename T2, typename F>
12 inline
13 typename common_type<T1, T2>::type
14 promote_common(const F& u) {
15 return promoter<F, typename common_type<T1, T2>::type>
16 ::promote_to(u);
17 }
18
19 }
20 }
21
22
23 #endif
stan
Definition: log_sum_exp.hpp:8
promoter.hpp
stan::math::promote_common
common_type< T1, T2 >::type promote_common(const F &u)
Definition: promote_common.hpp:14
common_type.hpp
stan::math::promoter
Definition: promoter.hpp:14

[ Stan Home Page ] © 2011–2016, Stan Development Team.